// I don't trust the adhesive cable tie mounts, so I'm building
// mounts I can screw down with half inch wood screws to hold the
// small wire ties. I imagine I'll need lots of these inside the
// box to keep things organized.

// Actual measured dimensions of the wire ties I have (I'll want
// to addin some slop for sure).
//
wire_tie_thick=1.15;
wire_tie_wide=2.71;

// Dimensions I used for the screws in my spice holders. I'll use the
// same screws for these.
//
screw_head_diameter=8.5;
screw_shaft_diameter=3.9;
screw_head_height=2.5;


// long skinny cube shaped like a wire tie to subtract off the cleat to
// allow holes for the wire tie to go through
//
module wire_shape(thick=wire_tie_thick,wide=wire_tie_wide,long=50,grow=1.30) {
   xlen=wide*grow;
   zlen=thick*grow;
   translate([-xlen/2,-long/2,0])
      cube([xlen,long,zlen]);
}

// The screw hole to subtract off the cleat for printing
//
module screw_hole(
   head_dia=screw_head_diameter,
   shaft_dia=screw_shaft_diameter,
   head_height=screw_head_height,
   screw_len=30) {
   rotate([0,180,0])
      union() {
         cylinder(r1=(head_dia/2),
                  r2=(shaft_dia/2),
                  h=head_height,
                  $fn=32);
         cylinder(r=(shaft_dia/2),
                  h=screw_len,
                  $fn=32);
         translate([0,0,-(screw_len-0.01)])
            cylinder(r=(head_dia/2),
                     h=screw_len,
                     $fn=32);
      }
}

// I'm just winging all the dimensions here till it looks good in the
// preview window

module cable_tie_1() {
   difference() {
      polyhedron(
        points=[ [10,10,0],[10,-10,0],[-10,-10,0],[-10,10,0],
                 [0,0,15]  ],
        faces=[ [0,1,4],[1,2,4],[2,3,4],[3,0,4],
                    [1,0,3],[2,1,3] ] );
      translate([0,0,2.5])
         wire_shape();
      rotate([0,0,90])
         translate([0,0,2.5])
            wire_shape();
      translate([0,0,2.5])
         screw_hole();
      translate([-(screw_head_diameter+0.5)/2,-(screw_head_diameter+0.5)/2,2.5])
         cube([screw_head_diameter+0.5,screw_head_diameter+0.5,20]);
      translate([-25,-25,6])
         cube([50,50,50]);
   }
}

// Make an array of 16 for printing lots at once.
//
module cable_tie_16() {
   for (i=[0 : 22 : 66]) {
      for (j=[0 : 22 : 66]) {
         translate([i,j,0])
            cable_tie_1();
      }
   }
}
