include <vslot20x20.scad>
include <hexnut.scad>

// Attach this to printbed rail to hold pipe cleaner for running nozzle
// through just before printing to clean off ooze. I gave up on
// trying to do a clip on or press fit, this just includes bolt holes
// to clamp the thing in place.

// Some (approx) measurements:
//
// horizontal distance between inside of rail and edge of printbed: 32mm
//
// vertical distance between top of rail and top of printbed: 4mm
//
// thickness of glass cover: 2.8mm
//
// The closer the pipe cleaner is held to the printbed, the less the
// nozzle will be able to knock it out of position. The more secure the
// cleaner is mounted to the rail, the less the nozzle will be able
// to knock it out of position.

// shape used to punch a slot at the back of the channel the pipe cleaner
// can be pulled through.
//
module slot_hole(len=7) {
   union() {
      sphere(r=3/2,$fn=64);
      rotate([0,90,0])
         cylinder(r=3/2,h=len,$fn=64);
      rotate([0,180,0])
         cylinder(r=3/2,h=len,$fn=64);
      translate([0,-(3/2),-len])
         cube([len,3,len]);
   }
}

module pipe_holder() {
   union() {
      difference() {
         cube([30,30,7]);
         translate([5,2+3/2,7/2])
            rotate([0,90,0])
               cylinder(r=3/2,h=30,$fn=64);
         translate([5,2+3/2,7/2])
            slot_hole();
         translate([5,30-(2+3/2),7/2])
            rotate([0,90,0])
               cylinder(r=3/2,h=30,$fn=64);
         translate([5,30-(2+3/2),7/2])
            slot_hole();
         translate([25,0,7])
            rotate([0,25,0])
               translate([0,-1,0])
                  cube([30,32,7]);
      }
      translate([0,0,7/2])
         difference() {
            rotate([-90,0,0])
               cylinder(r=7/2,h=30,$fn=64);
            translate([-32/2,-1,-33])
               cube([32,32,32]);
         }
   }
}

module rail_clamp() {
   wall=3.2;
   difference() {
      cube([20+9,30,20+2*wall]);
      translate([-wall,-1,wall])
         cube([20.2+9,32,20.2]);
      translate([2+3/2,2+3/2,-1])
         cylinder(r=3.3/2,h=40,$fn=64);
      translate([2+3/2,30-(2+3/2),-1])
         cylinder(r=3.3/2,h=40,$fn=64);
   }
}

module cleaner() {
   union() {
      rotate([90,0,0])
         union() {
            rail_clamp();
            translate([26.1,0,(4)+20+3.2-7/2])
               pipe_holder();
         }
      // Block inside so brim won't run into it
      translate([0,-24,0])
         cube([0.2,22,0.2]);
   }
}

// cleaner();

// YIKES! All that stuff works, but the cooling fan hits it, so
// start again...

module m3bolt() {
   m3head_height=3;
   m3head_dia=6;

   rotate([0,90,0])
   union() {
      cylinder(r=3.2/2,h=35,$fn=64);
      translate([0,0,-1])
         cylinder(r=m3head_dia/2,h=m3head_height+1,$fn=64);
      translate([0,0,32+27])
         hexnut(m3nut_flat+0.3,32);
   }
}

// This one attaches to the bottom of the rail and the only thing sticking
// up are the bits of pipe cleaner. I've got the pipe cleaner run up and
// down through all 4 holes now, but it might actually work better with just
// one loop of pipe cleaner and two holes.
//
module new_cleaner(do_left=true) {
   wid=30;

   difference() {
      // Big honking cube to "wrap around" print rail.
      translate([-(10+3),0,0])
         cube([20+3+32,wid,9+16]);
      // Subtract off central part where v-rail will go
      translate([-(20-2*1.5)/2,-1,9+1.5])
         cube([20-2*1.5,wid+2,20]);
      // Subtract off v-rail shape to leave bits sunk into rail slots
      translate([0,-1,10+3+3+3])
         rotate([-90,0,0])
            vslot20x20(wid+2);
      // Subtract off holes for M3 bolts to to screw left and right halfs
      // together
      translate([-(10+3),3+1.5,3+1.5])
         m3bolt();
      translate([-(10+3),wid-(3+1.5),3+1.5])
         m3bolt();
      // Subtract off 4 holes for running pipe cleaner vertically
      translate([10+32-(3+1.5),wid/5,-1])
         cylinder(r=3.2/2,h=9+16+2,$fn=64);
      translate([10+32-(3+1.5),2*(wid/5),-1])
         cylinder(r=3.2/2,h=9+16+2,$fn=64);
      translate([10+32-(3+1.5),3*(wid/5),-1])
         cylinder(r=3.2/2,h=9+16+2,$fn=64);
      translate([10+32-(3+1.5),4*(wid/5),-1])
         cylinder(r=3.2/2,h=9+16+2,$fn=64);
      // Get rid of excess plastic I don't need (this leaves an extreme
      // overhang which doesn't print very well, but good enough to
      // hold a pipe cleaner with a little cleanup).
      translate([10+32,-1,0])
         rotate([-90,0,0])
            scale([1,0.8,1])
               cylinder(r=(9+16),h=wid+2,$fn=64);
      // Get rid of half we don't want to render based on do_left arg
      if (do_left) {
         translate([-0.1,-1,-1])
            cube([10+32+5,wid+2,9+16+2]);
      } else {
         translate([(-(10+3+1))+0.1,-1,-1])
            cube([10+3+1,wid+2,9+16+2]);
      }
   }
}

// The pipe cleaner thing is a pain the way the above is constructed. Let's
// add a platform I can clamp to the sides of the old cleaner to hold the
// pipe cleaners so I can adjust the platform to get them in the right
// place rather than trying to get the pipe cleaner bent to an exact position.

// The top of the new clamp has holes for the pipe cleaner and ears sticking
// out the side to go in slots on the clamp sides.
//
module clamp_top() {
   difference() {
      union() {
         // main body
         cube([30,30,6]);
         // ears sticking out the sides
         translate([10,-4,0])
            cube([10,38,3]);
      }
      for ( i = [0:4] ) {
         translate([0,0,1.5+3/2])
            rotate([0,90,0])
               translate([0,3+6*i,-1])
                  cylinder(r=3/2,h=32,$fn=64);
      }
   }
}

// One side of the clamp has a nut trap, the other just a hole for the M3 bolt
//
module clamp_side(do_nut=1) {
   difference() {
      cube([16,30,4]);
      translate([3,3,-1])
         cube([10.5,3.5,6]);
      if (do_nut) {
         translate([8,10,8])
            hexnut(m3nut_flat+0.3,6);
      }
      translate([8,10,-1])
         cylinder(r=3.2/2,h=6,$fn=64);
   }
}
