// Dimensions of the angle iron (which is really aluminum). These have
// a bit of slop added to them

ai_longside=19.5+0.5;
ai_shortside=13+0.5;
ai_thick=1.66+0.1;

// Base diameter of cone rotor sits on.

r_holedia=12;

// How far supports stick out from rail

suphigh=25;

// How long along the rail is the switch box

boxlen=35;

// Subtract this from the top of the box to make a hole for the switch
// to be bolted to.
//
module switch_hole () {
   len = 10.52 + 0.3;
   wid = 5.66 + 0.3;
   sep = 15;
   union() {
      translate([-wid/2,-len/2,0])
         cube([wid,len,10]);
      translate([0,-sep/2,0])
         cylinder(r=2.3/2,h=10,$fn=64);
      translate([0,sep/2,0])
         cylinder(r=2.3/2,h=10,$fn=64);
   }
}

// Subtract this shape from the rotating bits to hold a piece of angle iron
// (aluminum, really) this dimension (which the LED strip with be stuck
// to). This has a long and short side. The LEDs go on the short side so the
// long side overhangs them and serves as a reflector (even more reflective
// if I stick some aluminum tape on it).

module angle_iron(len=5) {
   longside=ai_longside;
   shortside=ai_shortside;
   thick=ai_thick;
   difference() {
      union() {
         cube([thick,len,shortside]);
         translate([0,0,shortside-thick])
            cube([longside,len,thick]);
         translate([0,0,shortside-(thick+1)])
            cube([thick+1,len,thick+1]);
      }
      translate([thick+1,-1,shortside-(thick+1)])
         rotate([-90,0,0])
            cylinder(r=1,h=len+2,$fn=64);
   }
}

// The rotor pieces have holes (to rotate around) and inset slots to hold
// the angle iron as well as a "handles" on top to grab them and
// rotate. They don't need to rotate a lot, just enough to adjust the angle
// of the LEDs a bit.
//
module rotor(do_left=true) {
   holedia=r_holedia;

   mirror([do_left?1:0,0,0])
   difference() {
      union() {
         cube([ai_longside+3+3,4+ai_shortside+3+3,5]);
         translate([((ai_longside+3+3)-5)/2,-6,0])
         union() {
            cube([5,7,5]);
            translate([5/2,0,0])
               cylinder(r=5/2,h=5,$fn=64);
         }
      }
      translate([3,ai_shortside+3,3])
         rotate([90,0,0])
            angle_iron();
      translate([13.5,13.5,-0.1])
         cylinder(r1=holedia/2,r2=(holedia-2)/2,h=5.2,$fn=64);
   }
}

// The wall that has the cone holding the support. I use this on the
// left support and the box with the wiring.
//
module support_wall(do_left=true) {
   translate([do_left?0:3,0,0])
   mirror([do_left?0:1,0,0])
   difference() {
      union() {
         cube([3,20,suphigh]);
         translate([3-0.1,11.5,16.5])
            rotate([0,90,0])
               cylinder(r1=(r_holedia-0.3)/2,r2=(r_holedia-2.3)/2,h=5.2,$fn=64);
      }
      if (! do_left) {
         translate([-3,11.5,16.5])
            rotate([0,90,0])
               cylinder(r=5.2/2,h=20,$fn=64);
      }
   }
}

// Support for the left side rotor, no wires here, just holding up the
// end.
//
module left_support() {
   difference() {
      union() {
         cube([15,20,4]);
         translate([15-3,0,0])
            support_wall();
      }
      translate([6,10,-1])
         cylinder(r=5.2/2,h=6,$fn=64);
   }
}

// A slide in top for the switch box, passing in non-zero "extra" will
// inflate the dimensions a bit so it can be used to subtract a hole where
// it fits.
//
module box_top(extra=0) {
   mylen=(boxlen-2)+extra;
   mywid=(20-4)+extra;
   myhi=3+extra;
   angl=30;

   difference() {
      cube([mylen,mywid,myhi]);
      rotate([0,angl,0])
         translate([-10,-1,0])
            cube([10,mywid+2,10]);
      rotate([-angl,0,0])
         translate([-1,-10,0])
            cube([mylen+2,10,10]);
      translate([0,mywid,0])
         rotate([angl,0,0])
            translate([-1,0,0])
               cube([mylen+2,10,10]);
   }
}

// Box to hold the switch and wiring at the right end of the top rail.
// Also has a cone for support like the left end, but this one has a hole
// in it to admit the wires from the LED strip. A slide-in top is also provided
// to hide everything after getting it all connected.
//
module switch_box() {
   difference() {
      union() {
         // left side of box has cone for rotor and hole to let
         // LED wires into box
         support_wall(false);
         difference() {
            // What prints as bottom but will be the back attached to
            // rail has hole in moddle for M5 bolt
            cube([boxlen,20,4]);
            translate([4+(11/2),20/2,-1])
               cylinder(r=5.2/2,h=6,$fn=64);
         }
         translate([boxlen-3,0,0])
            difference() {
               // right side of box has small hole to admit 12V power wires
               cube([3,20,suphigh]);
               translate([-1,20/2,suphigh/2])
                  rotate([0,90,0])
                     cylinder(r=4/2,h=5,$fn=64);
            }
         difference() {
            // what will be the top of the box has hole for bolting switch
            // into place (may need supports to print this). [Amazing - printed
            // really well with no supports]
            cube([boxlen,3,suphigh]);
            translate([2+(boxlen/2),5,(suphigh/2)-2])
               rotate([90,0,0])
                  rotate([0,0,90])
                     switch_hole();
         }
         // what will be bottom of box is actually solid, no holes in this.
         translate([0,20-3,0])
            cube([boxlen,3,suphigh]);
         // Add a solid top that will be mostly subtracted off when sliding
         // top shape is subtracted from it.
         translate([0,0,suphigh-3])
            cube([boxlen,20,3]);
         
      }
      // Now I need to subtract off the sliding box top (will face away from
      // rail when mounted).
      translate([2,2,suphigh-3])
         box_top(0.2);
   }
}
