// Hack up the knurled knob downloaded from thingiverse to use for
// an adjustment knob on the three leveling screws on the jiggit
// print bed, Sink an m5 washer half way into the top to give
// so the washer will be turning against the aluminum, not the plastic.
//
// Imported 1_inch_knob.stl downloaded from:
// https://www.thingiverse.com/thing:177400/files
//
// Though perhaps I should have used this openscad library
// instead of hacking an existing stl object:
// https://www.thingiverse.com/thing:32122
//
// Perhaps I should have put the nut and washer at the top of a short
// "tower" to give finger clearance instead of jamming it against
// the bottom of the bed, but trying it out, doesn't seem hard to
// adjust without that, and the screws might need to be longer if I
// added the tower. The knob also sticks out beyond the aluminum channel
// pieces a little bit, so that also makes it easy to turn. 

m5washer_dia=9.79;
m5washer_thick=0.91;

include <hexnut.scad>

module big_knob() {
   union() {
      // import the 1 inch diameter knurled knob, and raise it up to zero
      // instead of below the z axis.
      translate([0,0,12.7])
         import("1_inch_knob.stl");

      // union with cylinder to plug up the 1/4-20 nut and hole
      cylinder(r=10,h=12.7);
   }
}

module top_knob() {
   // shift it down to cut layer of knurling off top.
   difference() {
      translate([0,0,-9.5])
         big_knob();
      translate([0,0,-50])
         cylinder(r=30,h=50);
   }
}

module thin_knob() {
   // translate it all back up to zero.
   translate([0,0,3.2])
   union() {
      // take the top part
      translate([0,0,-0.01])
         top_knob();
      // flip it over and union together to make thicker (but not as thick
      // as original) knob.
      rotate([0,180,0])
         top_knob();
   }
}

difference() {
   // Start with knob
   thin_knob();
   // subtract out m5 nut shape as deep as a nut plus half
   // thickness of washer
   translate([0,0,(m5nut_thick+5+6.4)-(m5nut_thick+(m5washer_thick/2))])
      hexnut(m5nut_flat+0.2,m5nut_thick+5);
   // subtract out shape for m5 washer half the thickness of the washer
   translate([0,0,6.4-(m5washer_thick/2)])
      cylinder(r=(m5washer_dia+0.2)/2,h=m5washer_thick,$fn=64);
   // subtract out hole for m5 bolt
   translate([0,0,-1])
      cylinder(r=(5.2)/2,h=10,$fn=64);
}
