// Somewhat silly nameplate to slide into a t-slot extrusion. Prints two
// pieces that need to be glued together.

include <jiggit.scad>
include <vslot20x20.scad>

// i_dot is a small arc to connect the dot to the i
module i_dot() {
   translate([0,0,2])
      difference() {
         rotate([0,90,0])
            difference() {
               translate([-2,-2,0])
                  cube([4,4,2]);
               translate([0,0,-1])
                  cylinder(r=1, h=4, $fn=64);
            }
         translate([-25,-25,0])
            cube([50,50,50]);
      }
}

// The name Jiggit with all the letters joined up
module nameplate() {
   translate([0,8,0])
      difference() {
         union() {
            // The letters
            jiggit(3);
            // Connects the dots
            translate([-18,5.5,0])
               i_dot();
            translate([15.5,5.5,0])
               i_dot();
            // Connect all the letters
            translate([-25,-(6-0.2)/2,0])
               cube([50,6-0.2,2]);
         }
         // Cut a channel out of the bottom to mate with a ridge on mount
         translate([-70/2,0,0])
            rotate([0,90,0])
               cylinder(h=70,r=0.9,$fn=64);
      }
}

// The slide to fit into the t-slot and glue to the back of the name
module nameslide() {
   botw=6;
   topw=11.5;
   ht=3.3;
   sltw=5.8;
   slth=2.2;

   translate([-25,-20,0])
   union() {
      rotate([0,0,90])
         rotate([90,0,0])
            linear_extrude(height=50)
               polygon([[(topw-botw)/2,0],
                        [topw-((topw-botw)/2),0],
                        [topw,ht],
                        [topw-((topw-sltw)/2),ht],
                        [topw-((topw-sltw)/2),ht+slth],
                        [(topw-sltw)/2,ht+slth],
                        [(topw-sltw)/2,ht],
                        [0,ht]]);
      translate([0,topw/2,ht+slth])
         rotate([0,90,0])
            cylinder(r=0.85,h=50,$fn=64);
   }
}

// Arrange both pieces to print together as one stl file.
union() {
   nameslide();
   nameplate();
}
