// Dimensions to use for the ducts that blow air below the print head.
//
ductdia=15;
ductlen=32;
ductwall=1.44;
ductfloor=1.2;
ductangle=-29;
ductsep=21;
extrasep=6;
ductbasex=ductdia;
ductbasey=(2*ductsep)+ductdia;

// These dimensions for the radial fan blower come from the solidoodle aero
// conversion project (same model radial fan).
//
fan_inner_wide=16.7+0.6;
fan_inner_high=12.7+0.6;
fan_wall=1.27;
fan_clip_high=2.06;
fan_clip_thick=1.5;
fan_clip_off=5.85;
fan_extra_wall=2;

// One single duct
//
module oneduct(rot=ductangle) {
   ow=7; // opening width
   rotate([0,0,rot])
      difference() {
         union() {
            cylinder(r=ductdia/2,h=ductlen,$fn=64);
            translate([0,0,ductlen])
               sphere(r=ductdia/2,$fn=64);
         }
         union() {
            translate([0,0,-1])
               cylinder(r=(ductdia/2)-ductwall,h=ductlen+1,$fn=64);
            translate([0,0,ductlen])
               sphere(r=(ductdia/2)-ductwall,$fn=64);
         }
         translate([-ow/2,0,19])
            union() {
               cube([ow,35,10]);
               translate([ow/2,0,0])
                  rotate([-90,0,0])
                     cylinder(r=ow/2,h=35,$fn=64);
               translate([ow/2,0,10])
                  rotate([-90,0,0])
                     cylinder(r=ow/2,h=35,$fn=64);
            }
      }
}

// Both ducts plus the base they are joined to
//
module twoduct() {
   edby=ductbasey+2*extrasep;
   difference() {
      union() {
         translate([0,ductsep+extrasep,0])
            oneduct(rot=180-ductangle);

         translate([0,-(ductsep+extrasep),0])
            oneduct(rot=ductangle);

         translate([-ductbasex/2,-edby/2,0])
            cube([ductbasex,edby,ductfloor]);
      }
      translate([0,ductsep+extrasep,-1])
         cylinder(r=(ductdia/2)-ductwall,h=ductfloor+2,$fn=64);
      translate([0,-(ductsep+extrasep),-1])
         cylinder(r=(ductdia/2)-ductwall,h=ductfloor+2,$fn=64);
   }
}

// Bottom of the air distribution box. This will need to be printed with
// supports so the hole the fan sticks in prints nicely. (Stole a lot of this
// from the aero modification for the solidoodle, so I know the opening
// fits the fan properly).
//
module fan_opening(high=2.5) {
   dbx=ductbasex+2*ductwall;
   dby=ductbasey+2*ductwall;
   edby=dby+2*extrasep;
   wall=fan_wall;
   vent_x=fan_inner_high+2*fan_wall;
   vent_y=fan_inner_wide+2*fan_wall;
   outer_x=vent_x+2*wall;
   outer_y=vent_y+2*wall;
   clip_off=((vent_x)/2)-fan_clip_off;
   translate([0,0,high])
   rotate([0,180,0])
   union() {
      difference() {
         translate([-dbx/2,-edby/2,0])
            cube([dbx,edby,high]);
         translate([0,(-dby/2)+(outer_y/2),0])
         union() {
            translate([-fan_inner_high/2,-fan_inner_wide/2,-1])
               cube([fan_inner_high,fan_inner_wide,high+2]);
            translate([-clip_off,-(fan_inner_wide/2+fan_wall+fan_clip_thick),high/2])
               cube([fan_clip_high,fan_clip_thick+fan_wall+1,high]);
            translate([-(vent_x)/2,-(vent_y)/2,
                       high/2])
               cube([vent_x,vent_y,1+high/2]);
         }
      }
   }
}

// Fan fits into opening (which needs supports to print) and vane divides
// air flow in two for each side.
//
module airbox(high=2.5) {
   dbx=ductbasex+2*ductwall;
   vby=ductbasey+2*ductwall;
   dby=2*extrasep+vby;
   wall=fan_wall;
   vent_y=fan_inner_wide+2*fan_wall;
   outer_y=vent_y+2*wall;
   union() {
      fan_opening(high=high);
      // box walls
      translate([-dbx/2,-dby/2,high/2])
         cube([dbx,ductwall,dbx-high/2]);
      translate([-dbx/2,(dby/2)-ductwall,high/2])
         cube([dbx,ductwall,dbx-high/2]);
      translate([dbx/2-ductwall,-dby/2,high/2])
         cube([ductwall,dby,dbx-high/2]);
      translate([-dbx/2,-dby/2,high/2])
         cube([ductwall,dby,dbx-high/2]);
      // Add internal supports for corners to make it easier to glue
      translate([-ductbasex/2,-(ductbasey+2*extrasep)/2,high/2])
         cylinder(r=1.2,h=16.7-high/2,$fn=64);
      translate([ductbasex/2,-(ductbasey+2*extrasep)/2,high/2])
         cylinder(r=1.2,h=16.7-high/2,$fn=64);
      translate([-ductbasex/2,(ductbasey+2*extrasep)/2,high/2])
         cylinder(r=1.2,h=16.7-high/2,$fn=64);
      translate([ductbasex/2,(ductbasey+2*extrasep)/2,high/2])
         cylinder(r=1.2,h=16.7-high/2,$fn=64);
      // Supports to attach to beams
      difference() {
         union() {
            translate([ductbasex/2,18,0])
               cube([21,5,10]);
            translate([ductbasex/2,-29.5,0])
               cube([21,5,10]);
         }
         // Poke M2 screw hole through supports to match hole in beams.
         translate([24.5,40,3.2])
            rotate([90,0,0])
               cylinder(r=1.1,h=80,$fn=64);
         // Slice slot out of supports to support attachment of the fan
         translate([dbx/2,-(24.5+2.2),-1])
            cube([5.2,42.5+4.4,30]);
      }
      // connect two cylinders to produce vane
      hull() {
         // cylinder for the bottom of the vane that divides the flow
         translate([-dbx/2,(-vby/2)+(outer_y/2),ductwall/2+high/2])
            rotate([0,90,0])
               cylinder(r=ductwall/2,h=dbx,$fn=64);
         // cylinder for the top of the vane just past duct
         translate([-dbx/2,(-vby/2)+(outer_y/2)+5,16.7-ductwall/2])
            rotate([0,90,0])
               cylinder(r=ductwall/2,h=dbx,$fn=64);
      }
   }
}

// Shape used to print M2 nut trap upside down
module m2shape() {
   nut_flat=3.9;
   nut_rad=0.4+(nut_flat*0.577);
   union() {
      translate([0,0,nut_rad])
         sphere(r=nut_rad,$fn=6);
      translate([0,0,nut_rad])
         cylinder(r=nut_rad,h=10,$fn=6);
      translate([0,0,-10])
         cylinder(r=2.4/2,h=15,$fn=64);
   }
}

// Final piece needed for assembly, fan screws to this and plate on top
// slides into slots in the supports till fan is in position (then it gets
// glued in place).
//
module fantop() {
   dbx=ductbasex+2*ductwall;
   difference() {
      union() {
         translate([dbx/2,-(24.5+2),-2])
            cube([5,42.5+4,12]);
         translate([(dbx/2)-1.4,-26.5,-42])
            cube([5+1.4,6,41]);
         translate([(dbx/2)-1.4,14,-7])
            cube([5+1.4,6,6]);
         hull() { 
            translate([dbx/2-1.4,19.1,-5.25])
               rotate([0,90,0])
                  cylinder(r=8/2,h=5+1.4,$fn=64);
            translate([dbx/2-1.4,-23.85,-44.36])
               rotate([0,90,0])
                  cylinder(r=8/2,h=5+1.4,$fn=64);
         }
      }
      translate([11-2,19.1,-5.25])
         rotate([0,90,0])
            m2shape();
      translate([11-2,-23.85,-44.36])
         rotate([0,90,0])
            m2shape();
   }
}

// Yikes! I have this installed now, and the new problem is that it works so
// well, it cools off the heat block, making the print stop and give a
// warning. Might work to just reduce the fan speed in cura, but a better
// idea would be some nozzles I can slide over the existing tubes to route
// the air more directly to just under the hot end nozzle.

// Finally decided how to make the "nozzle" to blow under the heat block.
// I'm going to position 8 points in space and use them in various combinations
// with the hull() function to generate the nozzle shape and punch the hole
// in the cylinder.
nozrad=2*0.48;
nozpts=[[5,5,nozrad],        // points of square inside nozzle shape
        [-5,5,nozrad],
        [5,5,19-nozrad],
        [-5,5,19-nozrad],
        [1,5+12,nozrad],        // points at end of nozzle under heat block
        [-3,5+11,nozrad],
        [1,5+12,19-nozrad],
        [-3,5+11,19-nozrad],
        [0,3,22],                     // peak of roof
        [-1,5+11.5,19-nozrad]
];

module nozzle_duct(do_outer=1) {
   rad=do_outer?nozrad:0.3;
   if (! do_outer) {
      // Make a solid block to subtract the hole for the nozzle
      hull() {
         for ( i = [0:9] ) {
            translate(nozpts[i])
               sphere(r=rad,$fn=64);
         }
      }
   } else {
      // union together the hulls for the 4 sides to make the duct itself
      union() {
         // bottom
         hull() {
            translate(nozpts[0])
               sphere(r=rad,$fn=64);
            translate(nozpts[1])
               sphere(r=rad,$fn=64);
            translate(nozpts[4])
               sphere(r=rad,$fn=64);
            translate(nozpts[5])
               sphere(r=rad,$fn=64);
         }
         // top is a bridge too far to print flat, so I need to make a
         // sloped roof to get it to print nicely which means two separate
         // hulls for the two roof panels
         hull() {
            translate(nozpts[2])
               sphere(r=rad,$fn=64);
            translate(nozpts[8])
               sphere(r=rad,$fn=64);
            translate(nozpts[6])
               sphere(r=rad,$fn=64);
            translate(nozpts[9])
               sphere(r=rad,$fn=64);
         }
         hull() {
            translate(nozpts[8])
               sphere(r=rad,$fn=64);
            translate(nozpts[3])
               sphere(r=rad,$fn=64);
            translate(nozpts[9])
               sphere(r=rad,$fn=64);
            translate(nozpts[7])
               sphere(r=rad,$fn=64);
         }
         // left
         hull() {
            translate(nozpts[0])
               sphere(r=rad,$fn=64);
            translate(nozpts[2])
               sphere(r=rad,$fn=64);
            translate(nozpts[4])
               sphere(r=rad,$fn=64);
            translate(nozpts[6])
               sphere(r=rad,$fn=64);
         }
         // right
         hull() {
            translate(nozpts[1])
               sphere(r=rad,$fn=64);
            translate(nozpts[3])
               sphere(r=rad,$fn=64);
            translate(nozpts[5])
               sphere(r=rad,$fn=64);
            translate(nozpts[7])
               sphere(r=rad,$fn=64);
         }
      }
   }
}

// Wrap around the current nozzle cylinder and redirect the air to just below
// the hot end tip.
//
module nozzle() {
   slop=0.2;
   hi=18;
   translate([0,ductsep+extrasep,0])
   rotate([0,0,180-ductangle])
   difference() {
      union() {
         cylinder(r=(ductdia/2)+ductwall+slop,h=hi,$fn=64);
         translate([0,0,hi])
            sphere(r=(ductdia/2)+ductwall+slop,$fn=64);
         nozzle_duct();
      }
      translate([0,0,-1])
         union() {
            cylinder(r=(ductdia/2)+slop,h=hi+1,$fn=64);
            translate([0,0,hi+1])
               sphere(r=(ductdia/2)+slop,$fn=64);
         }
      nozzle_duct(do_outer=0);
   }
}
