// Looks like the actual E3D will be about 20mm lower than it was, so if
// I can raise the groove mount some on the new part, that would be good.
//
// This (in theory) holds the orion higher with the orion parts themselves
// extending back inside the two X carriage plates between the wheels.
// It also moves the hot end left a few millimeters to get out of the
// way of the cable chain mount, and the bolts are now accessible on top
// of the carriage instead of being a pain to get to under the carriage.
//
// Lots of commented out stuff in here I was using to visualize how
// things go together and make sure the holes are in the right places.

include <carriages.scad>

// Module for visualizing the Orion groove mount so I can see how it fits
//
module orion_view() {
   import("/home/tom/3d/jiggit/orion/files/Orion_Groove_Top_-3NS.stl");
   translate([0,0,-3])
      rotate([180,0,0])
         rotate([0,0,90])
            import("/home/tom/3d/jiggit/orion/files/Orion_Groove_Clamp_-3NS.stl");
}

//translate([4+8,-3,-4.5])
//orion_view();

//translate([-plate_y/2,0,0])
//rotate([0,0,90])
//x_carriage();

//translate([0,0,-2*(wheel_spacer+wheel_thick/2)])
//rotate([180,0,0])
//translate([-plate_y/2,0,0])
//rotate([0,0,90])
//x_carriage(false);

//translate([0,17,-(plate_thick+3+5)])
//rotate([0,90,0])
//x_chain_mount();

//e3d_mount();

// This piece is unioned to the top above the groove mount where the
// orion goes. It has a support for the PTFE tube, a slot for wire ties, and
// a disk to join with the vertical support for added strength.
//
module above_hotend() {
   rad=13;
   difference() {
      union() {
         translate([0,0,-1])
            cube([9,e3d_big_dia+12,17]);
         translate([0,((e3d_big_dia+12)/2)-10/2,15-3])
            cube([4+(e3d_big_dia/2),10,4]);
         translate([4+(e3d_big_dia/2),((e3d_big_dia+12)/2),15-3])
            cylinder(r=10/2,h=4,$fn=64);
         rotate([0,90,0])
            cylinder(r=rad,h=4,$fn=64);
      }
      translate([-1,4,-3])
         cube([11,e3d_big_dia+4,15]);
      translate([4+(e3d_big_dia/2),((e3d_big_dia+12)/2),0])
         cylinder(r=4.5/2,h=50,$fn=64);
      translate([-1,-25,-51])
         cube([50,50,50]);
      translate([9/2,e3d_big_dia+12+1,4])
         rotate([90,0,0])
            cylinder(r=3.5/2,h=6,$fn=64);
      translate([9/2,e3d_big_dia+12+1,8])
         rotate([90,0,0])
            cylinder(r=3.5/2,h=6,$fn=64);
      translate([(-3.5/2)+9/2,(-6)+e3d_big_dia+12+1,4])
         cube([3.5,6,4]);
   }
}

// This is the entire mount as a single piece, it gets sliced across the
// moddle of the groove to make the back and front pieces. It avoids
// the cable chain on the right, but has additional support running down to
// the lower X carriage on the left for extra support and stability.
//
module whole_new_mount(do_back=true) {
   tot_high = (e3d_top_thick+e3d_mid_thick+e3d_bot_thick)-0.5;
   ylen=e3d_big_dia+8+8;

   difference() {
      translate([0,-5-ylen/2,0])
         union() {
            cube([e3d_big_dia+e3d_offset,ylen+5,tot_high]);
            translate([0,-9,0])
               cube([4,ylen+5+9,tot_high]);
            translate([0,-9,-(plate_thick+3+10+2*(wheel_spacer+wheel_thick/2))])
               cube([4,9,50]);
            if (do_back) {
               translate([0,4,12.5])
                  above_hotend();
            }
         }
      translate([12,-3,-0.5])
         e3d_top();
      translate([-10,10,plate_thick+3])
         rotate([0,90,0])
            cylinder(r=3.02/2,h=50,$fn=64);
      translate([-10,10-25,plate_thick+3])
         rotate([0,90,0])
            cylinder(r=3.02/2,h=50,$fn=64);
      translate([-10,10-35,plate_thick+3])
         rotate([0,90,0])
            cylinder(r=3.02/2,h=50,$fn=64);
      translate([-10,10-35,plate_thick+3+5])
         rotate([0,90,0])
            cylinder(r=3.02/2,h=50,$fn=64);
      translate([-10,10-35,-(plate_thick+3+2*(wheel_spacer+wheel_thick/2))])
         rotate([0,90,0])
            cylinder(r=3.02/2,h=50,$fn=64);
      translate([-10,10-35,-(plate_thick+3+5+2*(wheel_spacer+wheel_thick/2))])
         rotate([0,90,0])
            cylinder(r=3.02/2,h=50,$fn=64);
   }
}

module new_mount(do_back=true) {
   translate([do_back?0:5,do_back?0:5,do_back?0:e3d_big_dia+e3d_offset])
      rotate([0,do_back?-90:90,0])
         difference() {
            whole_new_mount(do_back);
            translate([do_back?12:12-100,-50,-80])
            cube([100,100,100]);
         }
}

// Generate both parts to make a single stl to print both at once
module both_parts() {
   new_mount();
   new_mount(false);
}

//above_hotend();

//whole_new_mount();

// cylinder the size of e3dv6 heat sink
//translate([12,-3,-75])
//#cylinder(r=22.3/2,h=50,$fn=64);

both_parts();
