include <vslot20x20.scad>

// Piece that can be shoved in a vslot rail and turned 90 degrees to
// grab the stot structure. Other types of things can be added to this
// to make various holders of wires and wot-not. (I bet I could even
// embed an M2 or possibly M3 nut in one).
//
// This piece is 5.87mm high and 5.34mm wide (after the scale operation).
//
// Printing horizontally seems to work better than printing vertically
// (the slightly squished 1st layer seems to help provide a more positive
// fit).
//
module vslot_insert_base() {
   sw=5.5;
   c=20-0.1;
   // The fit is too tight at 100%, 97% seems to work well.
   scale([0.97,0.97,0.97])
   // take slice out of rotated shape just wide enough to fit through slot
   rotate([180,0,0])
   difference() {
      // rotate shape of slot 360 degrees
      rotate_extrude(angle=360,$fn=64)
         // Take a single plane slice of just the slot shape
         projection(cut=true)
            translate([0,3.9,-0.1])
               difference() {
                  // Subtract a 20x20 vslot from a cube and cut off all the
                  // excess bits of that except for a single slot shape.
                  translate([-c/2,-c/2,0])
                     cube([c,c,1]);
                  translate([0,0,-1])
                     vslot20x20(3);
                  translate([-(c+2)/2,-3.9,-1])
                     cube([c+2,c+2,3]);
                  translate([-16,-10,-1])
                     cube([10,10,3]);
                  translate([6,-10,-1])
                     cube([10,10,3]);
                  translate([0,0,-1])
                     rotate([0,0,-45])
                        cube([10,10,3]);
                  mirror([1,0,0])
                     translate([0,0,-1])
                        rotate([0,0,-45])
                           cube([10,10,3]);
                  translate([0,-25,-1])
                     cube([50,50,50]);
               }
      translate([-10,sw/2,-19])
         cube([20,sw,20]);
      mirror([0,1,0])
         translate([-10,sw/2,-19])
            cube([20,sw,20]);
   }
}
