include <carriages.scad>

// M3 locknut dimensions
//
m3_locknut_flat=5.43;
m3_locknut_thick=3.76;

// Utility to make a shape that is a "shaft" with a hex nut on the end
// for subtracting off things to leave a hole where a nut can go.
//
module hextrap(flat, thick, len) {
   union() {
      hexnut(flat, thick);
      translate([0, -flat/2, -thick])
         cube([len,flat,thick]);
   }
}

// Piece I can glue to print bed Z carriage to hold a screw that will serve as
// an adjustable Z-stop. I can do coarse adjustment by sliding the switch up
// and down the rail, and fine adjustment by turning the screw in the
// trapped lock nut on this piece. I may need a longer version of ystop
// to get the switch positioned to make contact with the screw (or a bigger
// cap to stick on the end of the screw to make it harder to miss).
//
module zstop() {
   thick=m3_locknut_thick+3+3;
   top=(8-(m3_locknut_thick+0.2))/2;
   translate([0,0,4+8])
   rotate([-90,0,0])
   difference() {
      union() {
         // thin cube goes on top edge of Z carriage
         cube([thick,4+8,top]);
         // thick cube holds trapped lock nut for M3 screw
         translate([0,4,0])
            cube([thick,8,8]);
      }
      // Subtract off hole for lock nut to be trapped in
      translate([thick/2,4+8/2,(m3_locknut_thick+0.2+8)/2])
         rotate([0,0,-90])
            hextrap(m3_locknut_flat+0.2, m3_locknut_thick+0.2, 10);
      // Subtract off hole for M3 screw
      translate([thick/2, 4+8/2, -1])
         cylinder(r=3.2/2, h=10, $fn=64);
   }
}

// Print piece to glue to Z carriage and hold locknut and screw
//
zstop();

// Print extended length switch holder to go on vertical rail and
// allow switch to hit the screw.
//
translate([30,-25,0])
   rotate([0,-90,0])
      ystop(do_back=true, do_preview=false, elen=4);

// And print normal length switch holder for Z limit switch
//
translate([30,-30,0])
   rotate([0,-90,0])
      ystop(do_back=false, do_preview=false, elen=0);
